==> wrogue-0.7.5.tar.bz2: wrogue-0.7.5/src/terrain.h <==
/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * Module Name: Terrain
 * Description: -
 */


/*
 * terrain attributes
 */
typedef enum {

	TA_NIL = -1,
	
	TA_IMPASSABLE,
	TA_BLOCKS_LINE_OF_SIGHT,
	TA_CAUSES_DISEASE,
	TA_AIR,
	TA_DANGEROUS,
	
	TA_OUT_OF_BOUNDS

} TERRAIN_ATTRIBUTE;


/*
 * static terrain data
 */
typedef struct {

	char 			name[TERRAIN_NAME_SIZE];

	bool			attribute[MAX_TERRAIN_ATTRIBUTES];

	SYMBOL			symbol;

	DYNAMIC_COLOR		color;

} TERRAIN_DATA;


void			terrain_init(void);
void			terrain_clean_up(void);

TERRAIN_DATA *		terrain_box_new_terrain(void);
void			terrain_box_optimize(void);

const TERRAIN_DATA *	terrain_static_data(const TERRAIN *);

bool			terrain_has_attribute(const TERRAIN *, TERRAIN_ATTRIBUTE);

TERRAIN *		terrain_create(const char *);
TERRAIN *		terrain_create_i(TERRAIN_INDEX);

void			terrain_destroy(void *);

TERRAIN *		terrain_clone(const TERRAIN *);

void			terrain_screen(const TERRAIN *);

char *			terrain_description(char *, const TERRAIN *);

const char *		terrain_attribute_name(TERRAIN_ATTRIBUTE);

void			terrain_cause_disease(CHARACTER *);

bool			terrain_dangerous_for(const CHARACTER *, const TERRAIN *);

TERRAIN_ATTRIBUTE	name_to_terrain_attribute(const char *);

==> wrogue-0.7.7b.tar.bz2: wrogue-0.7.7b/src/terrain.h <==
/*
 * Copyright (C) 2002-2007 The Warp Rogue Team
 * Part of the Warp Rogue Project
 *
 * This software is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License.
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY.
 *
 * See the license.txt file for more details.
 */

/*
 * Module Name: Terrain
 * Description: -
 */



/*
 * static terrain data
 */
typedef struct {

	char 			name[TERRAIN_NAME_SIZE];

	SYMBOL			symbol;

	DYNAMIC_COLOUR		colour;

	char			description[DESCRIPTION_SIZE];

	bool			attribute[MAX_TERRAIN_ATTRIBUTES];

} TERRAIN_DATA;



void			terrain_init(void);
void			terrain_clean_up(void);

TERRAIN_DATA *		terrain_box_new_terrain(void);
void			terrain_box_optimize(void);

void *			terrain_new(void);
void			terrain_free(void *);

TERRAIN *		terrain_create(const char *);
TERRAIN *		terrain_create_i(TERRAIN_INDEX);

void			terrain_destroy(void *);

TERRAIN *		terrain_clone(const TERRAIN *);

void			terrain_screen(const TERRAIN *);

void			terrain_attribute_screen(TERRAIN_ATTRIBUTE);

const TERRAIN_DATA *	terrain_static_data(const TERRAIN *);

bool			terrain_has_attribute(const TERRAIN *,
				TERRAIN_ATTRIBUTE
			);

const char *		terrain_attribute_name(TERRAIN_ATTRIBUTE);

char *			terrain_attribute_description(char *,
				TERRAIN_ATTRIBUTE
			);

void			terrain_cause_disease(CHARACTER *);

bool			terrain_dangerous_for(const CHARACTER *,
				const TERRAIN *
			);

TERRAIN_ATTRIBUTE	name_to_terrain_attribute(const char *);
